==> seven-elements-1.0.2%2B1.21.6-sources.jar: io/github/xrickastley/sevenelements/mixin/WindChargeItemMixin.java <==
package io.github.xrickastley.sevenelements.mixin;

import com.llamalad7.mixinextras.injector.ModifyReturnValue;
import com.llamalad7.mixinextras.sugar.Local;

import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import io.github.xrickastley.sevenelements.util.JavaScriptUtil;
import net.minecraft.class_1657;
import net.minecraft.class_1676;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2350;
import net.minecraft.class_2374;
import net.minecraft.class_8956;
import net.minecraft.class_9239;

@Mixin(class_9239.class)
public class WindChargeItemMixin {
	@ModifyReturnValue(
		method = "method_61665",
		at = @At("RETURN")
	)
	private static class_8956 setElementalInfusion1(class_8956 original, @Local(argsOnly = true) class_1657 user) {
		final @Nullable class_1799 stack = JavaScriptUtil.nullishCoalesing(
			user.method_6047(),
			user.method_6079()
		);

		// Unable to resolve Wind Charge stack.
		if (stack == null) return original;

		original.sevenelements$setOriginStack(stack);
		return original;
	}

	@Inject(
		method = "createEntity",
		at = @At(
			value = "INVOKE",
			target = "Lnet/minecraft/entity/projectile/WindChargeEntity;setVelocity(Lnet/minecraft/util/math/Vec3d;)V"
		)
	)
	private void setElementalInfusion2(class_1937 world, class_2374 pos, class_1799 stack, class_2350 direction, CallbackInfoReturnable<class_1676> cir, @Local class_8956 windCharge) {
		windCharge.sevenelements$setOriginStack(stack);
	}
}

==> seven-elements-1.0.4%2B1.21-sources.jar: io/github/xrickastley/sevenelements/mixin/WindChargeItemMixin.java <==
package io.github.xrickastley.sevenelements.mixin;

import com.llamalad7.mixinextras.sugar.Local;

import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import io.github.xrickastley.sevenelements.util.JavaScriptUtil;
import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1657;
import net.minecraft.class_1676;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2350;
import net.minecraft.class_2374;
import net.minecraft.class_8956;
import net.minecraft.class_9239;

@Mixin(class_9239.class)
public class WindChargeItemMixin {
	@Inject(
		method = "use",
		at = @At(
			value = "INVOKE",
			target = "Lnet/minecraft/entity/projectile/WindChargeEntity;setVelocity(Lnet/minecraft/entity/Entity;FFFFF)V"
		)
	)
	private void setElementalInfusion1(class_1937 world, class_1657 user, class_1268 hand, CallbackInfoReturnable<class_1271<class_1799>> cir, @Local class_8956 windCharge) {
		final @Nullable class_1799 stack = JavaScriptUtil.nullishCoalesing(
			user.method_6047(),
			user.method_6079()
		);

		// Unable to resolve Wind Charge stack.
		if (stack == null) return;

		windCharge.sevenelements$setOriginStack(stack);
	}

	@Inject(
		method = "createEntity",
		at = @At(
			value = "INVOKE",
			target = "Lnet/minecraft/entity/projectile/WindChargeEntity;setVelocity(Lnet/minecraft/util/math/Vec3d;)V"
		)
	)
	private void setElementalInfusion2(class_1937 world, class_2374 pos, class_1799 stack, class_2350 direction, CallbackInfoReturnable<class_1676> cir, @Local class_8956 windCharge) {
		windCharge.sevenelements$setOriginStack(stack);
	}
}
